package aexp.hostapp;

import android.app.Activity;
import android.os.Bundle;
import android.os.IBinder;
import android.os.DeadObjectException;
import android.os.Handler;
import android.widget.Button;
import android.content.Intent;
import android.content.ComponentName;
import android.content.ServiceConnection;
import android.content.Context;
import android.util.Log;
import android.view.View;
import android.widget.TextView;
import aexp.aidl.IAdderService;

public class HostappClient extends Activity {
	public final static int ACTIVITY_INVOKE = 0;
    private static final String LOG_TAG = "HOSTAPP";
    private Handler uiHandler = new Handler();
	private TextView result = null;

    private IHostappServiceIF service = null;
    private HostappServiceConnection conn = null;

    class HostappServiceConnection implements ServiceConnection
    {
        public void onServiceConnected(ComponentName className, 
			IBinder boundService ) {
          service = IHostappServiceIF.Stub.asInterface((IBinder)boundService);
	      invokeService();
		  Log.d( LOG_TAG,"onServiceConnected" );
        }

        public void onServiceDisconnected(ComponentName className) {
          service = null;
		  Log.d( LOG_TAG,"onServiceDisconnected" );
        }
    };

    /** Called with the activity is first created. */
    @Override
    public void onCreate(Bundle icicle) {
        super.onCreate(icicle);
        setContentView(R.layout.main);
		initService();
        Button invokeButton = (Button) findViewById(R.id.invoke);
        invokeButton.setOnClickListener(new View.OnClickListener() {
            public void onClick(View view) {
			  Intent i = new Intent();
		      i.setClassName( "aexp.sclientapp", 
					"aexp.sclientapp.SClientApp" );
      			startSubActivity(i, ACTIVITY_INVOKE);
     		}
        });
    }

    @Override
    protected void onDestroy() {
	  super.onDestroy();
	  releaseService();
    }

	private void initService() {
	  conn = new HostappServiceConnection();
	  Intent i = new Intent();
	  i.setClassName( "aexp.hostapp", "aexp.hostapp.HostappServiceImpl" );
	  bindService( i, null, conn, Context.BIND_AUTO_CREATE);
	}

	private void releaseService() {
	  unbindService( conn );	  
	  conn = null;
	}

    private void invokeService() {
	  if( service == null )
		Log.e( LOG_TAG, "Service not available" );
	  else {
		try {
		  service.setCallback( setTextService.asBinder() );
		} catch( DeadObjectException ex ) {
		  Log.e( LOG_TAG, "DeadObjectException" );
		}
	  }
	}

    private ISetTextService.Stub setTextService 
				= new ISetTextService.Stub() {
        public void setMyText(final String textToSet ) {
            Log.d( LOG_TAG, "setMyText(" + textToSet + ")");

            uiHandler.post(new Runnable() {
                public void run() {
	  			  TextView t = (TextView)findViewById(R.id.invoke_result);
				  t.setText( textToSet );
                }
            });
        }
    };

}
